@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2012 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -48,6 +48,7 @@
 
 package RT::Test::GnuPG;
 use strict;
+use warnings;
 use Test::More;
 use base qw(RT::Test);
 use File::Temp qw(tempdir);
@@ -68,8 +69,10 @@ sub import {
     $t->plan( skip_all => 'gpg executable is required.' )
       unless RT::Test->find_executable('gpg');
 
-    require RT::Crypt::GnuPG;
     $class->SUPER::import(%args);
+    require RT::Crypt::GnuPG;
+    return $class->export_to_level(1)
+        if $^C;
 
     RT::Test::diag "GnuPG --homedir " . RT->Config->Get('GnuPGOptions')->{'homedir'};
 
